@@ -10,7 +10,7 @@ from concurrent.futures import (
     ProcessPoolExecutor, ThreadPoolExecutor, as_completed)
 from datetime import datetime
 from logging import getLogger
-from multiprocessing import Manager, Queue
+from multiprocessing import Manager, Process, Queue
 from os import environ, getenv, symlink
 from os.path import relpath
 from pathlib import Path
@@ -19,6 +19,7 @@ from urllib.error import URLError
 from urllib.request import urlretrieve as download_url
 
 from invisibleroads_macros_disk import make_folder
+from invisibleroads_macros_web.port import find_open_port
 from jinja2 import Template
 
 from ..constants import (
@@ -28,6 +29,8 @@ from ..constants import (
     DISK_DEBOUNCE_IN_MILLISECONDS,
     DISK_POLL_IN_MILLISECONDS,
     HOST,
+    MAXIMUM_PORT,
+    MINIMUM_PORT,
     MODE_CODE_BY_NAME,
     MODE_NAMES,
     PORT,
@@ -43,7 +46,6 @@ from ..exceptions import (
     CrossComputeExecutionError)
 from ..macros.iterable import group_by
 from ..macros.security import DictionarySafe
-from ..macros.web import find_open_port
 from .configuration import (
     get_folder_plus_path,
     load_configuration)
@@ -240,6 +242,7 @@ class PodmanEngine(AbstractEngine):
             raise CrossComputeExecutionError(f'could not build "{image_name}"')
 
     def run(self, automation_definition, batch_folder, custom_environment):
+        automation_folder = automation_definition.folder
         container_id, port_packs = _run_podman_image(
             automation_definition, batch_folder, custom_environment)
         with _proxy_podman_ports(
@@ -256,7 +259,9 @@ class PodmanEngine(AbstractEngine):
             error.code = Error.COMMAND_NOT_RUNNABLE
             raise error
         elif return_code > 0:
-            error_text = (batch_folder / 'debug' / 'stderr.txt').read_text()
+            error_text = (
+                automation_folder / batch_folder / 'debug' / 'stderr.txt'
+            ).read_text()
             error = CrossComputeExecutionError(error_text.rstrip())
             error.code = return_code
             raise error
@@ -409,7 +414,9 @@ def _run_podman_image(automation_definition, batch_folder, custom_environment):
         command_terms = []
         for port_definition in port_definitions:
             port_id = port_definition.id
-            host_port = find_open_port()
+            host_port = find_open_port(
+                minimum_port=MINIMUM_PORT,
+                maximum_port=MAXIMUM_PORT)
             mode_name = port_definition.mode_name
             container_port = port_definition.number
             port_packs.append((port_id, host_port, mode_name))
@@ -490,15 +497,24 @@ def _run_podman_command(options, terms):
 def _work(automation_queue):
     try:
         while automation_pack := automation_queue.get():
-            automation_definition = automation_pack[0]
-            engine = get_script_engine(
-                automation_definition.engine_name, with_rebuild=False)
-            update_datasets(automation_definition)
-            try:
-                engine.run_batch(*automation_pack)
-            except CrossComputeError as e:
-                e.automation_definition = automation_definition
-                L.error(e)
+            worker_process = Process(
+                target=_work_one, args=(automation_pack,), daemon=True)
+            worker_process.start()
+    except KeyboardInterrupt:
+        pass
+
+
+def _work_one(automation_pack):
+    try:
+        automation_definition = automation_pack[0]
+        engine = get_script_engine(
+            automation_definition.engine_name, with_rebuild=False)
+        update_datasets(automation_definition)
+        try:
+            engine.run_batch(*automation_pack)
+        except CrossComputeError as e:
+            e.automation_definition = automation_definition
+            L.error(e)
     except KeyboardInterrupt:
         pass
 
