@@ -6,10 +6,9 @@ from configparser import ConfigParser
 from datetime import timedelta
 from logging import getLogger
 from os import environ
-from os.path import basename, relpath, splitext
+from os.path import basename, relpath
 from pathlib import Path
 from string import Template
-from time import time
 
 import tomli
 from invisibleroads_macros_log import format_path
@@ -30,7 +29,6 @@ from ..constants import (
     MODE_NAMES,
     PRINTER_BY_NAME,
     RUN_ROUTE,
-    STYLE_ROUTE,
     VARIABLE_ID_PATTERN,
     VARIABLE_ID_TEMPLATE_PATTERN,
     VIEW_BY_NAME)
@@ -81,6 +79,7 @@ class AutomationDefinition(Definition):
         self._validation_functions = [
             validate_protocol,
             validate_automation_identifiers,
+            validate_authorization,  # Must run before validate_imports
             validate_imports,
             validate_variables,
             validate_variable_views,
@@ -92,7 +91,7 @@ class AutomationDefinition(Definition):
             validate_display_styles,
             validate_display_templates,
             validate_display_pages,
-            validate_authorization,
+            validate_display_buttons,
             validate_prints,
         ]
 
@@ -137,6 +136,16 @@ class AutomationDefinition(Definition):
                 design_name = 'none'
         return design_name
 
+    def get_button_text(self, button_id):
+        button_text = BUTTON_TEXT_BY_ID[button_id]
+        button_definition_by_id = self.button_definition_by_id
+        if button_id in button_definition_by_id:
+            button_definition = button_definition_by_id[button_id]
+            button_configuration = button_definition.configuration
+            button_text = button_configuration.get(
+                'button-text', button_text)
+        return button_text
+
 
 class VariableDefinition(Definition):
 
@@ -264,6 +273,15 @@ class PageDefinition(Definition):
         ]
 
 
+class ButtonDefinition(Definition):
+
+    def _initialize(self, kwargs):
+        self._validation_functions = [
+            validate_button_identifiers,
+            validate_button_configuration,
+        ]
+
+
 class TokenDefinition(Definition):
 
     def _initialize(self, kwargs):
@@ -501,7 +519,7 @@ def validate_batches(configuration):
     for raw_batch_definition in raw_batch_definitions:
         batch_definitions.extend(get_batch_definitions(
             raw_batch_definition, automation_folder, variable_definitions))
-    if 'output' in configuration and not(batch_definitions):
+    if 'output' in configuration and not batch_definitions:
         raise CrossComputeConfigurationError(
             'no batches configured; please define at least one batch')
     assert_unique_values([
@@ -566,32 +584,24 @@ def validate_scripts(configuration):
 def validate_display_styles(configuration):
     display_dictionary = get_dictionary(configuration, 'display')
     automation_folder = configuration.folder
-    automation_index = configuration.index
-    automation_uri = configuration.uri
-    reference_time = time()
     style_definitions = []
+    css_texts = []
     for raw_style_definition in get_dictionaries(
             display_dictionary, 'styles'):
         style_definition = StyleDefinition(raw_style_definition)
         style_uri = style_definition.uri
-        style_path = style_definition.path
         if '//' not in style_uri:
-            path = automation_folder / style_path
+            path = automation_folder / style_definition.path
             if not path.exists():
                 raise CrossComputeConfigurationError(
                     f'{path} not found for style')
-            style_name = format_slug(
-                f'{splitext(style_path)[0]}-{reference_time}')
-            style_uri = STYLE_ROUTE.format(style_name=style_name)
-            if automation_index > 0:
-                style_uri = automation_uri + style_uri
-            style_definition.path = style_path
-            style_definition.uri = style_uri
+            css_texts.append(path.read_text().rstrip())
+            continue
         style_definitions.append(style_definition)
-    css_uris = [_.uri for _ in style_definitions]
     return {
         'style_definitions': style_definitions,
-        'css_uris': css_uris,
+        'css_uris': [_.uri for _ in style_definitions],
+        'css_text': '\n'.join(css_texts) + '\n' if css_texts else '',
     }
 
 
@@ -620,6 +630,16 @@ def validate_display_pages(configuration):
     }
 
 
+def validate_display_buttons(configuration):
+    display_dictionary = get_dictionary(configuration, 'display')
+    button_definitions = [ButtonDefinition(_) for _ in get_dictionaries(
+        display_dictionary, 'buttons')]
+    button_definition_by_id = {_.id: _ for _ in button_definitions}
+    return {
+        'button_definition_by_id': button_definition_by_id,
+    }
+
+
 def validate_authorization(configuration):
     authorization_dictionary = get_dictionary(configuration, 'authorization')
     token_definitions = [TokenDefinition(_) for _ in get_dictionaries(
@@ -627,11 +647,10 @@ def validate_authorization(configuration):
     identities_by_token = {
         token: identities for _ in token_definitions
         for token, identities in _.identities_by_token.items()}
-    group_definitions = [GroupDefinition(_) for _ in get_dictionaries(
+    parent_group_definitions = getattr(configuration, 'group_definitions', [])
+    child_group_definitions = [GroupDefinition(_) for _ in get_dictionaries(
         authorization_dictionary, 'groups')]
-    if not group_definitions:
-        # Inherit group definitions from parent
-        group_definitions = getattr(configuration, 'group_definitions', [])
+    group_definitions = child_group_definitions + parent_group_definitions
     return {
         'identities_by_token': identities_by_token,
         'group_definitions': group_definitions,
@@ -709,7 +728,8 @@ def validate_batch_identifiers(batch_dictionary):
         except CrossComputeConfigurationNotImplementedError:
             raise
         except CrossComputeConfigurationError as e:
-            batch_configuration = batch_dictionary.get('configuration', {})
+            batch_configuration = get_dictionary(
+                batch_dictionary, 'configuration')
             if 'path' in batch_configuration:
                 e.path = batch_configuration['path']
             raise
@@ -843,7 +863,7 @@ def validate_page_identifiers(page_dictionary):
 
 
 def validate_page_configuration(page_dictionary):
-    page_configuration = page_dictionary.get('configuration', {})
+    page_configuration = get_dictionary(page_dictionary, 'configuration')
     page_id = page_dictionary['id']
     design_name = page_configuration.get('design')
     design_names = DESIGN_NAMES_BY_PAGE_ID[page_id]
@@ -855,6 +875,26 @@ def validate_page_configuration(page_dictionary):
     }
 
 
+def validate_button_identifiers(button_dictionary):
+    try:
+        button_id = button_dictionary['id']
+    except KeyError as e:
+        raise CrossComputeConfigurationError(f'{e} required for each button')
+    if button_id not in BUTTON_TEXT_BY_ID:
+        raise CrossComputeConfigurationError(
+            f'{button_id} button not supported for button configuration')
+    return {
+        'id': button_id,
+    }
+
+
+def validate_button_configuration(button_dictionary):
+    button_configuration = get_dictionary(button_dictionary, 'configuration')
+    return {
+        'configuration': button_configuration,
+    }
+
+
 def validate_token_identifiers(token_dictionary):
     try:
         token_path = token_dictionary['path']
@@ -1182,6 +1222,11 @@ DESIGN_NAMES_BY_PAGE_ID = {
 }
 
 
+BUTTON_TEXT_BY_ID = {
+    'run': 'Run',
+}
+
+
 INTERVAL_UNIT_NAMES = 'seconds', 'minutes', 'hours', 'days', 'weeks'
 
 
@@ -1203,7 +1248,7 @@ $function_string(**d)''')
 
 
 PERMISSION_IDS = [
-    'add_authorization',
+    'add_token',
     'see_root',
     'see_automation',
     'see_batch',
