@@ -1,6 +1,9 @@
 from logging import getLogger, DEBUG, ERROR
 from time import time
 
+from invisibleroads_macros_process import (
+    LoggableProcess,
+    StoppableProcess)
 from pyramid.config import Configurator
 from pyramid.events import NewResponse
 from waitress import serve
@@ -13,10 +16,9 @@ from ..constants import (
     PORT)
 from ..exceptions import (
     CrossComputeError)
-from ..macros.process import LoggableProcess, StoppableProcess
-from ..routes.authorization import AuthorizationRoutes
 from ..routes.automation import AutomationRoutes
 from ..routes.mutation import MutationRoutes
+from ..routes.token import TokenRoutes
 from .database import DiskDatabase
 from .interface import Server
 
@@ -44,7 +46,6 @@ class DiskServer(Server):
             getLogger('waitress').setLevel(ERROR)
         worker_process = LoggableProcess(
             name='worker', target=self._work, args=(self._queue,))
-        worker_process.daemon = True
         worker_process.start()
         # TODO: Decouple from pyramid and waitress
         host, port, root_uri = self._host, self._port, self._root_uri
@@ -106,13 +107,13 @@ def _get_app(
         settings.update({'pyramid.reload_templates': True})
     with Configurator(settings=settings) as config:
         config.include('pyramid_jinja2')
-        _configure_authorization_routes(
-            config, configuration, safe)
         _configure_automation_routes(
             config, configuration, safe, environment, queue)
         if with_refresh:
             _configure_mutation_routes(
                 config, server_timestamp, infos_by_timestamp)
+        _configure_token_routes(
+            config, configuration, safe)
         _configure_renderer_globals(
             config, with_refresh, with_restart, root_uri, server_timestamp,
             configuration)
@@ -122,11 +123,11 @@ def _get_app(
     return config.make_wsgi_app()
 
 
-def _configure_authorization_routes(
+def _configure_token_routes(
         config, configuration, safe):
-    authorization_routes = AuthorizationRoutes(
+    token_routes = TokenRoutes(
         configuration, safe)
-    config.include(authorization_routes.includeme)
+    config.include(token_routes.includeme)
 
 
 def _configure_automation_routes(
