@@ -9,6 +9,9 @@ from urllib.request import urlretrieve as download_uri
 from importlib_metadata import entry_points
 from invisibleroads_macros_log import format_path
 from invisibleroads_macros_text import format_name, format_slug
+from invisibleroads_macros_web.escape import (
+    escape_quotes_html,
+    escape_quotes_js)
 
 from ..constants import (
     CACHED_FILE_SIZE_LIMIT_IN_BYTES,
@@ -23,9 +26,6 @@ from ..exceptions import (
 from ..macros.disk import FileCache
 from ..macros.iterable import find_item
 from ..macros.package import import_attribute
-from ..macros.web import (
-    escape_quotes_html,
-    escape_quotes_js)
 from .interface import Batch
 
 
@@ -248,6 +248,8 @@ class TextView(VariableView):
 
     def render_input(self, b: Batch, x: Element):
         variable_definition = self.variable_definition
+        data = b.get_data_from_request(variable_definition)
+        value = data.get('value', '')
         variable_id = self.variable_id
         view_name = self.view_name
         element_id = x.id
@@ -257,6 +259,8 @@ class TextView(VariableView):
             'mode_name': self.mode_name,
             'view_name': view_name,
             'variable_id': variable_id,
+            'attribute_string': '' if value else ' disabled',
+            'value': value,
         })
         if x.design_name not in ['none']:
             main_text = add_label_html(main_text, c, variable_id, element_id)
@@ -264,11 +268,12 @@ class TextView(VariableView):
             STRING_JS_HEADER,
             STRING_JS_INPUT.substitute({'view_name': view_name}),
             TEXT_JS_HEADER,
-            TEXT_JS_INPUT.substitute({
+        ]
+        if not value:
+            js_texts.append(TEXT_JS_INPUT.substitute({
                 'element_id': element_id,
                 'data_uri': b.get_data_uri(variable_definition, x),
-            }),
-        ]
+            }))
         return {
             'css_uris': [],
             'js_uris': [],
